@@ -1,8 +1,5 @@
-import shutil
 import time
 
-from dagster_celery import celery_executor
-
 from dagster import (
     InputDefinition,
     Int,
@@ -16,6 +13,7 @@ from dagster import (
     solid,
 )
 from dagster.core.test_utils import nesting_composite_pipeline
+from dagster_celery import celery_executor
 
 celery_mode_defs = [ModeDefinition(executor_defs=default_executors + [celery_executor])]
 
@@ -67,13 +65,6 @@ def test_parallel_pipeline():
         add_one.alias("add_one_" + str(i))(value)
 
 
-@pipeline(mode_defs=celery_mode_defs)
-def test_more_parallel_pipeline():
-    value = simple()
-    for i in range(500):
-        add_one.alias("add_one_" + str(i))(value)
-
-
 COMPOSITE_DEPTH = 3
 
 
@@ -133,8 +124,7 @@ def test_retries():
 
 @solid(config_schema=str)
 def destroy(context, x):
-    shutil.rmtree(context.solid_config)
-    return x
+    raise ValueError()
 
 
 @pipeline(mode_defs=celery_mode_defs)
@@ -308,6 +298,12 @@ def hi_pipeline():
     sleep_solid.alias("hi_five")()
 
 
+@pipeline(mode_defs=celery_mode_defs)
+def interrupt_pipeline():
+    for i in range(50):
+        sleep_solid.alias("sleep_" + str(i))()
+
+
 # test_queues pipelines
 
 
